lambdaconnect-sync.push


compute-rel-objs-to-fetchclj

(compute-rel-objs-to-fetch config input entities-by-name snapshot)

Creates a map of {:umbrella [uuid1, uuid2, ...], :brick [buuid1, buudi2, ...]}. The map represents all objects that should be fetched to have the input data complete.

Creates a map of {:umbrella [uuid1, uuid2, ...], :brick [buuid1, buudi2, ...]}. 
The map represents all objects that should be fetched to have the input data complete.
sourceraw docstring

final-permissions-for-objectclj

(final-permissions-for-object permissions entity)
source

internal-push-transactionclj

(internal-push-transaction config
                           incoming-json
                           internal-user
                           snapshot
                           entities-by-name
                           scoped-push-input-for-user)
(internal-push-transaction config
                           incoming-json
                           internal-user
                           snapshot
                           entities-by-name
                           scoped-push-input-for-user
                           now)
source

merge-fieldsclj

(merge-fields perms entity)
source

merge-permissionsclj

(merge-permissions permissions)
source

push-transactionclj

(push-transaction config
                  incoming-json
                  internal-user
                  snapshot
                  entities-by-name
                  scoping-edn)
(push-transaction config
                  incoming-json
                  internal-user
                  snapshot
                  entities-by-name
                  scoping-edn
                  now)
(push-transaction config
                  incoming-json
                  internal-user
                  snapshot
                  entities-by-name
                  scoping-edn
                  push-output
                  rejections
                  cached-snapshot-tags)
source

send-specific-hooks!clj

(send-specific-hooks! config
                      before-snapshot
                      snapshot
                      interesting-objects
                      entities-by-name
                      user
                      hook-fun)

Creates a transaction

Creates a transaction
sourceraw docstring

send-specific-update-hooks!clj

(send-specific-update-hooks! config
                             before-snapshot
                             snapshot
                             interesting-objects
                             entities-by-name
                             user
                             hook-fun)

Creates a transaction

Creates a transaction
sourceraw docstring

update-boolean-permissionsclj

(update-boolean-permissions l r)
source

update-protected-fieldsclj

(update-protected-fields l-m r-m l r)
source

update-writable-fieldsclj

(update-writable-fields l-m r-m l r)
source

cljdoc builds & hosts documentation for Clojure/Script libraries