(compute-rel-objs-to-fetch config input entities-by-name snapshot)Creates a map of {:umbrella [uuid1, uuid2, ...], :brick [buuid1, buudi2, ...]}. The map represents all objects that should be fetched to have the input data complete.
Creates a map of {:umbrella [uuid1, uuid2, ...], :brick [buuid1, buudi2, ...]}.
The map represents all objects that should be fetched to have the input data complete.(internal-push-transaction config
incoming-json
internal-user
snapshot
entities-by-name
scoped-push-input-for-user)(internal-push-transaction config
incoming-json
internal-user
snapshot
entities-by-name
scoped-push-input-for-user
now)(push-transaction config
incoming-json
internal-user
snapshot
entities-by-name
scoping-edn)(push-transaction config
incoming-json
internal-user
snapshot
entities-by-name
scoping-edn
now)(push-transaction config
incoming-json
internal-user
snapshot
entities-by-name
scoping-edn
push-output
rejections
cached-snapshot-tags)(send-specific-hooks! config
before-snapshot
snapshot
interesting-objects
entities-by-name
user
hook-fun)Creates a transaction
Creates a transaction
(send-specific-update-hooks! config
before-snapshot
snapshot
interesting-objects
entities-by-name
user
hook-fun)Creates a transaction
Creates a transaction
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |